django-mongonaut — django-mongonaut 0.2.9 documentation

### Navigation

- index
- next |
- django-mongonaut 0.2.9 documentation »

# django-mongonaut

This is an introspective interface for Django and MongoDB. Built from scratch to replicate some of the Django admin functionality, but for MongoDB.

Contents:

- Installation
  - Normal Installation
  - Heroku MongoDB connection via MongoLabs
- Basic Usage
  - MongoAdmin: Fast and Easy
  - Advanced features of MongoAdmin
- Configuration
  - Basic Pattern
- Future Usage
- API
  - Sample Usage
  - MongoAdmin Listing
    - has_add_permission
    - has_edit_permission
    - has_edit_permission
    - has_view_permission
    - list_fields
    - search_fields

# Features

## Introspection of Mongo data

> - [in progress] Admin determination of which fields are displayed. Currently they can do so in the Document List view but not the Document Detail view.
> - [in progress] Introspection via pymongo (so you don’t need to define a schema ahead of time). This might be too much a jump in scope for this project, requiring a separate project. We’ll see.
> - Introspection via mongo engine
> - Q based searches
> - django.contrib.admin style browsing
> - Automatic detection of field types
> - Automatic discovery of collections

## Data Management

> - [in progress] Editing on ListFields, EmbeddedDocumentsFields, and ReferenceFields
> - [in progress] Document Deletes
> - [in progress] Admin authored Collection level document control functions
> - Editing on most other fields
> - Automatic detection of widget types
> - Text field shorthand for letting user quickly determine type when using without mongoengine
> - Document Adds

## Permissions

> - [in progress] Group defined controls
> - User level controls
> - Staff level controls
> - Admin defined controls

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-mongonaut 0.2.9 documentation »